@@ -1,5 +1,3 @@
 from nrel.hive.dispatcher.forecaster.basic_forecaster import BasicForecaster
 from nrel.hive.dispatcher.forecaster.forecast import Forecast, ForecastType
-from nrel.hive.dispatcher.forecaster.forecaster_interface import (
-    ForecasterInterface,
-)
+from nrel.hive.dispatcher.forecaster.forecaster_interface import ForecasterInterface
