@@ -6,15 +6,11 @@ from typing import Optional, TYPE_CHECKING, Tuple
 
 import immutables
 
-from nrel.hive.dispatcher.instruction.instruction_result import (
-    InstructionResult,
-)
+from nrel.hive.dispatcher.instruction.instruction_result import InstructionResult
 from nrel.hive.util.typealiases import VehicleId
 
 if TYPE_CHECKING:
-    from nrel.hive.state.simulation_state.simulation_state import (
-        SimulationState,
-    )
+    from nrel.hive.state.simulation_state.simulation_state import SimulationState
     from nrel.hive.runner.environment import Environment
 
 
