@@ -1,7 +1,8 @@
-from typing import Tuple, FrozenSet, Callable, TypeVar
+from typing import Tuple, FrozenSet
 
 from immutables import Map
 
+
 # MODEL ID TYPES
 RequestId = str
 VehicleId = str
@@ -13,11 +14,10 @@ PassengerId = str
 VehicleTypeId = str
 MechatronicsId = str
 ChargerId = str
-ScheduleId = str
 MembershipId = str
+ScheduleId = str
 
-Entity = TypeVar("Entity")
-EntityId = TypeVar("EntityId")
+EntityId = str
 
 # Collections
 MembershipMap = Map[EntityId, Tuple[MembershipId, ...]]
@@ -36,4 +36,4 @@ SimStep = int  # the iteration of the simulation
 
 # if we create a DriverId type, and it has a lookup table on SimulationState, we may
 # want to change this from VehicleId to DriverId
-ScheduleFunction = Callable[["SimulationState", VehicleId], bool]
+# ScheduleFunction = Callable[[SimulationState, VehicleId], bool]
